.. webapi-error::
   :title: Repository Information Error
   :instance: reviewboard.webapi.errors.REPO_INFO_ERROR

   The attempt to fetch server-side information on a repository failed due to
   some unknown reason. This may be a temporary outage. The request should be
   tried again, once you've checked that the repository's server is up and
   running.
